# stickydata
A package for correcting partitioning delays using deconvolution

Manuscript *in prep* for Environmental Science and Technology Air

## Installation

`pip install stickydata`

## Getting Started

The package currently supports deconvolution of single and double-exponential instrument response function. The relevant functions in the package are:
- Deconvolve_SingleExp
- Deconvolve_DblExp
- Deconvolve_DblExp_VariableIRF 

## Future Updates
Please contact demetriospagonis@weber.edu to discuss future updates
